@@ -448,6 +448,10 @@ define([
             return Config.ML_DATA_TYPES;
         }
 
+        getMLCategories() {
+            return Object.keys(Config.ML_DATA_DICT);
+        }
+
     }
 
     //========================================================================
@@ -462,7 +466,7 @@ define([
     /**
      * Version
      */
-    Config.version = "2.1.3";
+    Config.version = "2.2.0";
 
     /**
      * Type of mode
@@ -482,21 +486,6 @@ define([
      * Data types using for searching model variables
      */
     Config.ML_DATA_DICT = {
-        'Regression': [
-            'LinearRegression', 'Ridge', 'Lasso', 'ElasticNet', 'SVR', 'DecisionTreeRegressor', 'RandomForestRegressor', 'GradientBoostingRegressor', 'XGBRegressor', 'LGBMRegressor', 'CatBoostRegressor',
-        ],
-        'Classification': [
-            'LogisticRegression', 'BernoulliNB', 'MultinomialNB', 'GaussianNB', 'SVC', 'DecisionTreeClassifier', 'RandomForestClassifier', 'GradientBoostingClassifier', 'XGBClassifier', 'LGBMClassifier', 'CatBoostClassifier',
-        ],
-        'Auto ML': [
-            'AutoSklearnRegressor', 'AutoSklearnClassifier', 'TPOTRegressor', 'TPOTClassifier'
-        ],
-        'Clustering': [
-            'KMeans', 'AgglomerativeClustering', 'GaussianMixture', 'DBSCAN',
-        ],
-        'Dimension Reduction': [
-            'PCA', 'LinearDiscriminantAnalysis', 'TruncatedSVD', 'NMF', 'TSNE'
-        ],
         'Data Preparation': [
             /** Encoding */
             'OneHotEncoder', 'LabelEncoder', 'OrdinalEncoder', 'TargetEncoder', 'SMOTE',
@@ -504,16 +493,31 @@ define([
             'StandardScaler', 'RobustScaler', 'MinMaxScaler', 'Normalizer', 'FunctionTransformer', 'PolynomialFeatures', 'KBinsDiscretizer',
             /** ETC */
             'ColumnTransformer'
+        ],
+        'Regression': [
+            'LinearRegression', 'Ridge', 'Lasso', 'ElasticNet', 'SVR', 'DecisionTreeRegressor', 'RandomForestRegressor', 'GradientBoostingRegressor', 'XGBRegressor', 'LGBMRegressor', 'CatBoostRegressor',
+        ],
+        'Classification': [
+            'LogisticRegression', 'BernoulliNB', 'MultinomialNB', 'GaussianNB', 'SVC', 'DecisionTreeClassifier', 'RandomForestClassifier', 'GradientBoostingClassifier', 'XGBClassifier', 'LGBMClassifier', 'CatBoostClassifier',
+        ],
+        'Clustering': [
+            'KMeans', 'AgglomerativeClustering', 'GaussianMixture', 'DBSCAN',
+        ],
+        'Dimension Reduction': [
+            'PCA', 'LinearDiscriminantAnalysis', 'TruncatedSVD', 'NMF', 'TSNE'
+        ],
+        'Auto ML': [
+            'AutoSklearnRegressor', 'AutoSklearnClassifier', 'TPOTRegressor', 'TPOTClassifier'
         ]
     };
 
     Config.ML_DATA_TYPES = [
+        ...Config.ML_DATA_DICT['Data Preparation'],
         ...Config.ML_DATA_DICT['Regression'],
         ...Config.ML_DATA_DICT['Classification'],
-        ...Config.ML_DATA_DICT['Auto ML'],
         ...Config.ML_DATA_DICT['Clustering'],
         ...Config.ML_DATA_DICT['Dimension Reduction'],
-        ...Config.ML_DATA_DICT['Data Preparation']
+        ...Config.ML_DATA_DICT['Auto ML']
     ];
 
     return Config;
