@@ -47,7 +47,46 @@ define([
         // move to executed cell
         Jupyter.notebook.scroll_to_cell(Jupyter.notebook.get_selected_index());
 
-        com_util.renderSuccessMessage('Your code has been executed');
+        com_util.renderSuccessMessage('Your code is successfully generated.');
+    }
+
+    /**
+     * Insert multiple cells
+     * @param {String} type 
+     * @param {Array} commands 
+     * @param {boolean} exec 
+     * @param {int} sigNum 
+     */
+    var insertCells = function(type, commands, exec=true, sigNum=-1) {
+        var selectedIndex = getSelectedCell();
+        var targetCell = Jupyter.notebook.insert_cell_below(type, selectedIndex);
+
+        commands && commands.forEach((command, idx) => {
+            // Add signature
+            if (type == 'code' && sigNum >= 0) {
+                command = com_util.formatString('# VisualPython [{0}] - {1}\n', sigNum, idx + 1) + command
+            }
+            targetCell.set_text(command);
+            Jupyter.notebook.select_next();
+            if (exec) {
+                switch (type) {
+                    case "markdown":
+                        targetCell.render();
+                        break;
+                    case "code":
+                    default:
+                        targetCell.execute();
+                }
+            }
+
+            selectedIndex = getSelectedCell();
+            targetCell = Jupyter.notebook.insert_cell_below(type, selectedIndex);
+        });
+        
+        // move to executed cell
+        Jupyter.notebook.scroll_to_cell(Jupyter.notebook.get_selected_index());
+
+        com_util.renderSuccessMessage('Your code is successfully generated.');
     }
     
     var enableOtherShortcut = function() {
@@ -62,6 +101,7 @@ define([
     
     return {
         insertCell: insertCell,
+        insertCells: insertCells,
         enableOtherShortcut: enableOtherShortcut,
         disableOtherShortcut: disableOtherShortcut,
 
